@@ -8,19 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_dynamodb._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_s3._jsii
-import aws_cdk.aws_s3_assets._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-dynamodb-seeder",
-    "1.50.0",
+    "2.0.0",
     __name__[0:-6],
-    "cdk-dynamodb-seeder@1.50.0.jsii.tgz",
+    "cdk-dynamodb-seeder@2.0.0.jsii.tgz",
 )
 
 __all__ = [
